@@ -103,9 +103,16 @@ QString SortFilterModel::filterRole() const
 
 void SortFilterModel::setSortRole(const QString &role)
 {
-    QSortFilterProxyModel::setSortRole(roleNameToId(role));
+    if (m_sortRole == role) {
+        return;
+    }
     m_sortRole = role;
-    sort(0, sortOrder());
+    if (role.isEmpty()) {
+        sort(-1, Qt::AscendingOrder);
+    } else {
+        QSortFilterProxyModel::setSortRole(roleNameToId(role));
+        sort(0, sortOrder());
+    }
 }
 
 QString SortFilterModel::sortRole() const
@@ -180,6 +187,10 @@ void DataModel::dataUpdated(const QString &sourceName, const Plasma::DataEngine:
             QVariantHash::const_iterator i = m_dataSource->data().constBegin();
 
             while (i != m_dataSource->data().constEnd()) {
+                if (!m_sourceFilter.isEmpty() && m_sourceFilterRE.isValid() && !m_sourceFilterRE.exactMatch(i.key())) {
+                    ++i;
+                    continue;
+                }
                 QVariant value = i.value();
                 if (value.isValid() && value.canConvert<Plasma::DataEngine::Data>()) {
                     Plasma::DataEngine::Data data = value.value<Plasma::DataEngine::Data>();
