@@ -148,6 +148,8 @@ private:
     bool m_pressed;
     KDeclarativeMouseEvent* m_pressAndHoldEvent;
     QPointF m_pressAndHoldPosition;
+    //Important: used only for comparison. If you will ever need to access this pointer, make it a QWekapointer
+    QEvent *m_lastEvent;
 };
 
 #endif
